@@ -95,7 +95,7 @@ enum {
 };
 
 static char *column_names[COLUMNS_NB] = {
-	N_("Pid"), N_("User"), N_("Time"), N_("Command")
+	N_("PID"), N_("User"), N_("Time"), N_("Command")
 };
 
 enum {
@@ -972,7 +972,7 @@ load_target (DmaStart *this, const gchar *target)
 	if (mime_type == NULL)
 	{
 		anjuta_util_dialog_error(GTK_WINDOW (this->plugin->shell),
-				_("Unable to detect mime-type of %s. Debugger cannot start."), target);
+				_("Unable to detect MIME type of %s. Debugger cannot start."), target);
 		g_object_unref (file_info);
 		g_object_unref (file);
 		return FALSE;
