@@ -113,7 +113,7 @@ launch_application_failure (AnjutaFileLoaderPlugin *plugin,
 		gtk_widget_get_toplevel (GTK_WIDGET(ANJUTA_PLUGIN (plugin)->shell));
 	basename = g_path_get_basename (uri);
 	anjuta_util_dialog_error (GTK_WINDOW (parent),
-							  _("Can not open \"%s\".\n\n%s"),
+							  _("Cannot open \"%s\".\n\n%s"),
 							  basename, errmsg);
 	g_free (basename);
 }
@@ -258,7 +258,7 @@ open_with_dialog (AnjutaFileLoaderPlugin *plugin, const gchar *uri,
 								 "There is no plugin, default action, or application "
 								 "configured to handle this file type.\n"
 								 "\n"
-								 "Mime type: %s\n"
+								 "MIME type: %s\n"
 								 "\n"
 								 "You may choose to try opening it with the following "
 								 "plugins or applications."),
@@ -552,7 +552,7 @@ setup_file_filters (GtkFileChooser *fc)
 	gtk_file_chooser_add_filter (fc, filter);
 
 	filter = gtk_file_filter_new ();
-	gtk_file_filter_set_name (filter, _("Hyper text markup files"));
+	gtk_file_filter_set_name (filter, _("Hypertext markup files"));
 	gtk_file_filter_add_pattern (filter, "*.htm");
 	gtk_file_filter_add_pattern (filter, "*.html");
 	gtk_file_filter_add_pattern (filter, "*.xhtml");
@@ -561,7 +561,7 @@ setup_file_filters (GtkFileChooser *fc)
 	gtk_file_chooser_add_filter (fc, filter);
 
 	filter = gtk_file_filter_new ();
-	gtk_file_filter_set_name (filter, _("Shell scripts files"));
+	gtk_file_filter_set_name (filter, _("Shell script files"));
 	gtk_file_filter_add_pattern (filter, "*.sh");
 	gtk_file_chooser_add_filter (fc, filter);
 
@@ -889,7 +889,7 @@ static GtkActionEntry actions_file[] = {
 	{
 		"ActionFileOpen",
 		GTK_STOCK_OPEN,
-		N_("_Open..."),
+		N_("_Open…"),
 		"<control>o",
 		N_("Open file"),
 		G_CALLBACK (on_open_activate)
@@ -1230,7 +1230,7 @@ activate_plugin (AnjutaPlugin *plugin)
 	
 	loader_plugin = ANJUTA_PLUGIN_FILE_LOADER (plugin);
 	
-	DEBUG_PRINT ("%s", "AnjutaFileLoaderPlugin: Activating File Loader plugin...");
+	DEBUG_PRINT ("%s", "AnjutaFileLoaderPlugin: Activating File Loader plugin…");
 	
 	ui = anjuta_shell_get_ui (plugin->shell, NULL);
 	
@@ -1336,7 +1336,7 @@ deactivate_plugin (AnjutaPlugin *plugin)
 	
 	loader_plugin = ANJUTA_PLUGIN_FILE_LOADER (plugin);
 	
-	DEBUG_PRINT ("%s", "AnjutaFileLoaderPlugin: Deactivating File Loader plugin...");
+	DEBUG_PRINT ("%s", "AnjutaFileLoaderPlugin: Deactivating File Loader plugin…");
 	
 	/* Disconnect session */
 	g_signal_handlers_disconnect_by_func (G_OBJECT (plugin->shell),
