@@ -37,9 +37,10 @@
 #include <libanjuta/anjuta-debug.h>
 #include <libanjuta/anjuta-utils.h>
 #include <libanjuta/interfaces/ianjuta-wizard.h>
-
-#include <gnome.h>
+#include <stdlib.h>
 #include <glib/gi18n.h>
+#include <glib.h>
+#include <gdk/gdk.h>
 
 #include <gtk/gtk.h>
 
@@ -86,8 +87,6 @@ struct _NPWDruid
 	GtkLabel *error_message;
 	GtkWidget *error_detail;
 
-	GtkTooltips *tooltips;
-	
 	const gchar* project_file;
 	NPWPlugin* plugin;
 	
@@ -280,6 +279,7 @@ cb_druid_insert_project_icon (gpointer data, gpointer user_data)
 						DESC_COLUMN, _(npw_header_get_description (header)),
 						DATA_COLUMN, header,
 						-1);
+	
 	g_object_unref (pixbuf);
 }
 
@@ -312,6 +312,8 @@ cb_druid_insert_project_page (gpointer value, gpointer user_data)
 	
 	/* Fill icon view */
 	view = GTK_ICON_VIEW (gtk_builder_get_object (builder, PROJECT_LIST));
+	gtk_icon_view_set_pixbuf_column (view, PIXBUF_COLUMN);
+	gtk_icon_view_set_markup_column (view, TEXT_COLUMN);
 	store = gtk_list_store_new (4, GDK_TYPE_PIXBUF, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_POINTER);
 	g_list_foreach (template_list, cb_druid_insert_project_icon, store); 
 	gtk_icon_view_set_model (view, GTK_TREE_MODEL (store));
@@ -341,10 +343,8 @@ cb_druid_insert_project_page (gpointer value, gpointer user_data)
 static gboolean
 npw_druid_fill_selection_page (NPWDruid* druid)
 {
-	gboolean ok;
 	gchar* dir;
 	const gchar * const * sys_dir;
-	const gchar * user_dir;
  
 	/* Remove all previous data */
 	druid->project_book = GTK_NOTEBOOK (gtk_assistant_get_nth_page (GTK_ASSISTANT (druid->window), PROJECT_PAGE));
@@ -421,17 +421,7 @@ cb_druid_add_property (NPWProperty* property, gpointer user_data)
 		/* Set description tooltip */
 		if (description && (*description != '\0'))
 		{
-			GtkTooltips *tooltips;
-		
-			tooltips = data->druid->tooltips;
-			if (!tooltips)
-			{
-				tooltips = data->druid->tooltips = gtk_tooltips_new ();
-				data->druid->tooltips = tooltips;
-				g_object_ref (tooltips);
-				gtk_object_sink (GTK_OBJECT (tooltips));
-			}
-			gtk_tooltips_set_tip (tooltips, entry, description, NULL);
+			gtk_widget_set_tooltip_text (entry, description);
 		}
 
 		/* Add label and entry */
@@ -600,7 +590,7 @@ cb_save_valid_property (NPWProperty* property, gpointer user_data)
 		{
 		case NPW_FILENAME_RESTRICTION:
 			g_string_append_printf (data->error,
-									_("Field \"%s\" must start with a letter, a digit or an underscore and contains only letters, digits, underscore, minus and dot. Please fix it."),
+									_("Field \"%s\" must start with a letter, a digit or an underscore and contain only letters, digits, underscore, minus and dot. Please fix it."),
 									_(npw_property_get_label (property)));
 			break;
 		default:
@@ -812,11 +802,11 @@ check_and_warn_missing (NPWDruid *druid)
 		npw_druid_fill_error_page (druid,
 								   GTK_MESSAGE_WARNING,
 								  _("The missing programs are usually part of some distrubution "
-									"packages and can be searched in your Application Manager. "
+									"packages and can be searched for in your Application Manager. "
 									"Similarly, the development packages are contained in special "
-									"packages that your distribution provide to allow development "
-									"of projects based on them. They usually end with -dev or "
-									"-devel suffix in package names and can be found by searching "
+									"packages that your distribution provides to allow development "
+									"of projects based on them. They usually end with a \"-dev\" or "
+									"\"-devel\" suffix in package names and can be found by searching "
 									"in your Application Manager."),
 									"<b>%s</b>\n\n%s",
 									_("Missing components"),
@@ -1050,13 +1040,12 @@ npw_druid_new (NPWPlugin* plugin)
 	/* Check if autogen is present */
 	if (!npw_check_autogen())
 	{
-		anjuta_util_dialog_error (NULL, _("Could not find autogen version 5, please install the autogen package. You can get it from http://autogen.sourceforge.net"));
+		anjuta_util_dialog_error (NULL, _("Could not find autogen version 5; please install the autogen package. You can get it from http://autogen.sourceforge.net."));
 		return NULL;
 	}	
 
 	druid = g_new0(NPWDruid, 1);
 	druid->plugin = plugin;
-	druid->tooltips = NULL;
 	druid->project_file = NULL;
 	druid->busy = FALSE;
 	druid->page_list = g_queue_new ();
@@ -1083,12 +1072,6 @@ npw_druid_free (NPWDruid* druid)
 
 	g_return_if_fail (druid != NULL);
 
-	if (druid->tooltips)
-	{
-		g_object_unref (druid->tooltips);
-		druid->tooltips = NULL;
-	}
-	
 	/* Delete page list */
 	druid->next_page = PROPERTY_PAGE;
 	npw_druid_remove_following_page (druid);
