@@ -243,12 +243,12 @@ execute_with_terminal (RunProgramPlugin *plugin,
 	
 	if (launcher_path != NULL)
 	{
-		new_cmd = g_strconcat ("anjuta_launcher ", cmd, NULL);
+		new_cmd = g_strconcat ("anjuta-launcher ", cmd, NULL);
 		g_free (launcher_path);
 	}
 	else
 	{
-		DEBUG_PRINT("%s", "Missing anjuta_launcher");
+		DEBUG_PRINT("%s", "Missing anjuta-launcher");
 		new_cmd = g_strdup (cmd);
 	}
 
