@@ -24,6 +24,8 @@
 
 #include "subversion-log-dialog.h"
 
+#define BROWSE_BUTTON_LOG_DIALOG "browse_button_log_dialog"
+
 typedef struct
 {
 	glong revisions[2];
@@ -32,7 +34,7 @@ typedef struct
 
 typedef struct
 {
-	GladeXML *gxml;
+	GtkBuilder *bxml;
 	Subversion *plugin;
 	gchar *path;
 	GtkListStore *log_store;
@@ -67,8 +69,8 @@ on_diff_selected_column_toggled (GtkCellRendererToggle *renderer,
 						COL_REVISION, &revision,
 						-1);
 	
-	log_diff_selected_button = glade_xml_get_widget (data->gxml,
-													 "log_diff_selected_button");
+	log_diff_selected_button = GTK_WIDGET (gtk_builder_get_object (data->bxml,
+													 "log_diff_selected_button"));
 		
 	selected = !selected;
 		
@@ -108,7 +110,7 @@ create_columns (LogData *data)
 	GtkTreeViewColumn *column;
 	GtkCellRenderer *renderer;
 	
-	log_changes_view = glade_xml_get_widget (data->gxml, "log_changes_view");
+	log_changes_view = GTK_WIDGET (gtk_builder_get_object (data->bxml, "log_changes_view"));
 	
 	/* Selected for diff  */
 	column = gtk_tree_view_column_new ();
@@ -177,7 +179,7 @@ on_log_command_finished (AnjutaCommand *command, guint return_code,
 	gchar *full_log;
 		
 	g_object_ref (data->log_store);
-	log_changes_view = glade_xml_get_widget (data->gxml, "log_changes_view");
+	log_changes_view = GTK_WIDGET (gtk_builder_get_object (data->bxml, "log_changes_view"));
 	gtk_tree_view_set_model (GTK_TREE_VIEW (log_changes_view), NULL);
 	g_hash_table_remove_all (data->selected_diff_revisions);
 	
@@ -220,7 +222,7 @@ on_log_command_finished (AnjutaCommand *command, guint return_code,
 }
 
 static void
-on_log_view_button_clicked (GtkButton *button, LogData *data)
+subversion_show_log (LogData *data)
 {
 	GtkWidget *log_changes_view;
 	GtkWidget *log_file_entry;
@@ -231,14 +233,14 @@ on_log_view_button_clicked (GtkButton *button, LogData *data)
 	SvnLogCommand *log_command;
 	guint pulse_timer_id;
 	
-	log_changes_view = glade_xml_get_widget (data->gxml, "log_changes_view");
-	log_file_entry = glade_xml_get_widget (data->gxml, "log_file_entry");
-	log_diff_previous_button = glade_xml_get_widget (data->gxml,
-													 "log_diff_previous_button");
-	log_diff_selected_button = glade_xml_get_widget (data->gxml,
-													 "log_diff_selected_button");
-	log_view_selected_button = glade_xml_get_widget (data->gxml,
-													 "log_view_selected_button");
+	log_changes_view = GTK_WIDGET (gtk_builder_get_object (data->bxml, "log_changes_view"));
+	log_file_entry = GTK_WIDGET (gtk_builder_get_object (data->bxml, "log_file_entry"));
+	log_diff_previous_button = GTK_WIDGET (gtk_builder_get_object (data->bxml,
+													 "log_diff_previous_button"));
+	log_diff_selected_button = GTK_WIDGET (gtk_builder_get_object (data->bxml,
+													 "log_diff_selected_button"));
+	log_view_selected_button = GTK_WIDGET (gtk_builder_get_object (data->bxml,
+													 "log_view_selected_button"));
 	path = gtk_entry_get_text (GTK_ENTRY (log_file_entry));
 	
 	if (data->path)
@@ -253,7 +255,7 @@ on_log_view_button_clicked (GtkButton *button, LogData *data)
 		
 		pulse_timer_id = status_bar_progress_pulse (data->plugin,
 													  _("Subversion: Retrieving"
-														" log..."));
+														" log…"));
 		
 		g_signal_connect (G_OBJECT (log_command), "command-finished",
 						  G_CALLBACK (stop_status_bar_progress_pulse),
@@ -273,6 +275,12 @@ on_log_view_button_clicked (GtkButton *button, LogData *data)
 	gtk_list_store_clear (data->log_store);
 }
 
+static void
+on_log_view_button_clicked (GtkButton *button, LogData *data)
+{
+	subversion_show_log (data);
+}
+
 static void
 on_cat_command_data_arrived (AnjutaCommand *command, IAnjutaEditor *editor)
 {
@@ -320,7 +328,7 @@ on_log_view_selected_button_clicked (GtkButton *button, LogData *data)
 	IAnjutaEditor *editor;
 	guint pulse_timer_id;
 	
-	log_changes_view = glade_xml_get_widget (data->gxml, "log_changes_view");
+	log_changes_view = GTK_WIDGET (gtk_builder_get_object (data->bxml, "log_changes_view"));
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (log_changes_view));
 	gtk_tree_selection_get_selected (selection, &log_store, &selected_iter);
 	
@@ -341,7 +349,7 @@ on_log_view_selected_button_clicked (GtkButton *button, LogData *data)
 	
 	pulse_timer_id = status_bar_progress_pulse (data->plugin,
 												_("Subversion: Retrieving "
-												  "file..."));
+												  "file…"));
 	
 	g_signal_connect (G_OBJECT (cat_command), "command-finished",
 					  G_CALLBACK (stop_status_bar_progress_pulse),
@@ -399,6 +407,7 @@ on_log_diff_selected_button_clicked (GtkButton *button, LogData *data)
 		diff_command = svn_diff_command_new (data->path, 
 											 revision1,
 											 revision2,
+											 data->plugin->project_root_dir,
 											 TRUE);
 		
 		docman = anjuta_shell_get_interface (ANJUTA_PLUGIN (data->plugin)->shell,
@@ -415,7 +424,7 @@ on_log_diff_selected_button_clicked (GtkButton *button, LogData *data)
 		
 		pulse_timer_id = status_bar_progress_pulse (data->plugin,
 													_("Subversion: Retrieving " 
-													  "diff..."));
+													  "diff…"));
 		
 		g_signal_connect (G_OBJECT (diff_command), "command-finished",
 						  G_CALLBACK (stop_status_bar_progress_pulse),
@@ -455,7 +464,7 @@ on_log_diff_previous_button_clicked (GtkButton *button, LogData *data)
 	IAnjutaEditor *editor;
 	guint pulse_timer_id;
 	
-	log_changes_view = glade_xml_get_widget (data->gxml, "log_changes_view");
+	log_changes_view = GTK_WIDGET (gtk_builder_get_object (data->bxml, "log_changes_view"));
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (log_changes_view));
 	gtk_tree_selection_get_selected (selection, &log_store, &selected_iter);
 	
@@ -463,8 +472,11 @@ on_log_diff_previous_button_clicked (GtkButton *button, LogData *data)
 						COL_REVISION, &revision,
 						-1);
 	
-	diff_command = svn_diff_command_new (data->path, SVN_DIFF_REVISION_PREVIOUS,
-										 revision, TRUE); 
+	diff_command = svn_diff_command_new (data->path,
+										 SVN_DIFF_REVISION_PREVIOUS,
+										 revision,
+										 data->plugin->project_root_dir,
+										 TRUE);
 	
 	docman = anjuta_shell_get_interface (ANJUTA_PLUGIN (data->plugin)->shell,
 	                                     IAnjutaDocumentManager, NULL);
@@ -479,7 +491,7 @@ on_log_diff_previous_button_clicked (GtkButton *button, LogData *data)
 	
 	pulse_timer_id = status_bar_progress_pulse (data->plugin,
 												_("Subversion: Retrieving " 
-												  "diff..."));
+												  "diff…"));
 	
 	g_signal_connect (G_OBJECT (diff_command), "command-finished",
 					  G_CALLBACK (stop_status_bar_progress_pulse),
@@ -523,11 +535,11 @@ on_log_changes_view_row_selected (GtkTreeSelection *selection,
 	gchar *log_message;
 	
 	gtk_tree_model_get_iter (model, &iter, path);
-	log_message_text = glade_xml_get_widget (data->gxml, "log_message_text");
-	log_diff_previous_button = glade_xml_get_widget (data->gxml, 
-													 "log_diff_previous_button");
-	log_view_selected_button = glade_xml_get_widget (data->gxml,
-													 "log_view_selected_button");
+	log_message_text = GTK_WIDGET (gtk_builder_get_object (data->bxml, "log_message_text"));
+	log_diff_previous_button = GTK_WIDGET (gtk_builder_get_object (data->bxml, 
+													 "log_diff_previous_button"));
+	log_view_selected_button = GTK_WIDGET (gtk_builder_get_object (data->bxml,
+													 "log_view_selected_button"));
 	buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (log_message_text));
 	gtk_tree_model_get (model, &iter, 
 						COL_FULL_LOG, &log_message,
@@ -559,30 +571,34 @@ subversion_log_window_create (Subversion *plugin)
 	GtkWidget *log_diff_previous_button;
 	GtkWidget *log_diff_selected_button;
 	GtkWidget *log_view_selected_button;
+	GtkWidget *button;
 	GtkListStore *log_list_store;
 	GtkTreeSelection *selection;
 	
 	data = g_new0 (LogData, 1);
-	data->gxml = plugin->log_gxml;
+	data->bxml = plugin->log_bxml;
 	data->selected_diff_revisions = g_hash_table_new (g_direct_hash, 
 													  g_direct_equal);
 	data->plugin = plugin;
 	data->path = NULL;
 	
-	subversion_log = glade_xml_get_widget (plugin->log_gxml, "subversion_log");
-	subversion_log_vbox = glade_xml_get_widget (plugin->log_gxml, "subversion_log_vbox");
-	log_changes_view = glade_xml_get_widget (plugin->log_gxml, "log_changes_view");
-	log_whole_project_check = glade_xml_get_widget (plugin->log_gxml, 
-													"log_whole_project_check");
-	log_file_entry = glade_xml_get_widget (plugin->log_gxml, "log_file_entry");
-	log_view_button = glade_xml_get_widget (plugin->log_gxml, "log_view_button");
-	log_diff_previous_button = glade_xml_get_widget (plugin->log_gxml, 
-													 "log_diff_previous_button");
-	log_diff_selected_button = glade_xml_get_widget (plugin->log_gxml,
-													 "log_diff_selected_button");
-	log_view_selected_button = glade_xml_get_widget (plugin->log_gxml,
-													 "log_view_selected_button");
-	
+	subversion_log = GTK_WIDGET (gtk_builder_get_object (plugin->log_bxml, "subversion_log"));
+	subversion_log_vbox = GTK_WIDGET (gtk_builder_get_object (plugin->log_bxml, "subversion_log_vbox"));
+	log_changes_view = GTK_WIDGET (gtk_builder_get_object (plugin->log_bxml, "log_changes_view"));
+	log_whole_project_check = GTK_WIDGET (gtk_builder_get_object (plugin->log_bxml, 
+													"log_whole_project_check"));
+	log_file_entry = GTK_WIDGET (gtk_builder_get_object (plugin->log_bxml, "log_file_entry"));
+	log_view_button = GTK_WIDGET (gtk_builder_get_object (plugin->log_bxml, "log_view_button"));
+	log_diff_previous_button = GTK_WIDGET (gtk_builder_get_object (plugin->log_bxml, 
+													 "log_diff_previous_button"));
+	log_diff_selected_button = GTK_WIDGET (gtk_builder_get_object (plugin->log_bxml,
+													 "log_diff_selected_button"));
+	log_view_selected_button = GTK_WIDGET (gtk_builder_get_object (plugin->log_bxml,
+													 "log_view_selected_button"));
+	button = GTK_WIDGET (gtk_builder_get_object (plugin->log_bxml, BROWSE_BUTTON_LOG_DIALOG));
+	g_signal_connect(G_OBJECT(button), "clicked", 
+		G_CALLBACK(on_subversion_browse_button_clicked), log_file_entry);
+
 	g_signal_connect (G_OBJECT (log_view_button), "clicked",
 					  G_CALLBACK (on_log_view_button_clicked),
 					  data);
@@ -602,6 +618,7 @@ subversion_log_window_create (Subversion *plugin)
 	
 	g_object_set_data (G_OBJECT (log_whole_project_check), "fileentry",
 					   log_file_entry);
+	g_object_set_data (G_OBJECT (subversion_log_vbox), "log-data", data);
 	g_signal_connect (G_OBJECT (log_whole_project_check), "toggled",
 					  G_CALLBACK (on_whole_project_toggled), plugin);
 	init_whole_project (plugin, log_whole_project_check, FALSE);
@@ -647,24 +664,32 @@ void
 on_fm_subversion_log (GtkAction *action, Subversion *plugin)
 {
 	GtkWidget *log_file_entry;
+	GtkWidget *log_whole_project_check;
 	
-	log_file_entry = glade_xml_get_widget (plugin->log_gxml, "log_file_entry");
+	log_file_entry = GTK_WIDGET (gtk_builder_get_object (plugin->log_bxml, "log_file_entry"));
+	log_whole_project_check = GTK_WIDGET (gtk_builder_get_object (plugin->log_bxml,
+													"log_whole_project_check"));
 	
 	gtk_entry_set_text (GTK_ENTRY (log_file_entry), 
 						plugin->fm_current_filename);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (log_whole_project_check),
+								  FALSE);
 	
 	anjuta_shell_present_widget (ANJUTA_PLUGIN (plugin)->shell, 
 								 plugin->log_viewer, NULL);
+	
+	subversion_show_log (g_object_get_data (G_OBJECT (plugin->log_viewer), 
+											"log-data"));
 }
 
 void
-subversion_log_set_whole_project_sensitive (GladeXML *log_gxml, 
+subversion_log_set_whole_project_sensitive (GtkBuilder *log_bxml, 
 											gboolean sensitive)
 {
 	GtkWidget *log_whole_project_check;
 	
-	log_whole_project_check = glade_xml_get_widget (log_gxml,
-													"log_whole_project_check");
+	log_whole_project_check = GTK_WIDGET (gtk_builder_get_object (log_bxml,
+													"log_whole_project_check"));
 	
 	gtk_widget_set_sensitive (log_whole_project_check, sensitive);
 	
