@@ -200,17 +200,13 @@ goto_file_tag (SymbolDBPlugin *sdb_plugin, const gchar *word,
 		{
 			engine = sdb_plugin->sdbe_globals;
 		}		
-
-		iterator = NULL;
-		if (symbol_db_engine_is_connected (engine)) 
-		{		
-			iterator = symbol_db_engine_find_symbol_by_name_pattern (engine, 
-																 word,
-																 TRUE,
-																 SYMINFO_SIMPLE |
-																 SYMINFO_KIND |
-																 SYMINFO_FILE_PATH);
-		}
+						
+		iterator = symbol_db_engine_find_symbol_by_name_pattern (engine, 
+															 word,
+															 TRUE,
+															 SYMINFO_SIMPLE |
+															 SYMINFO_KIND |
+															 SYMINFO_FILE_PATH);
 	
 		if (iterator != NULL && symbol_db_engine_iterator_get_n_items (iterator) > 0)
 		{
@@ -310,13 +306,13 @@ on_find_symbol (GtkAction *action, SymbolDBPlugin *sdb_plugin)
 
 static GtkActionEntry actions[] = 
 {
-	{ "ActionMenuGoto", NULL, N_("_Goto"), NULL, NULL, NULL},
+	{ "ActionMenuGoto", NULL, N_("_Go to"), NULL, NULL, NULL},
 	{
 		"ActionSymbolDBGotoDecl",
 		ANJUTA_STOCK_GOTO_DECLARATION,
 		N_("Tag De_claration"),
 		"<shift><control>d",
-		N_("Goto symbol declaration"),
+		N_("Go to symbol declaration"),
 		G_CALLBACK (on_goto_file_tag_decl_activate)
 	},
 	{
@@ -325,14 +321,14 @@ static GtkActionEntry actions[] =
 		/* Translators: Go to the line where the tag is implemented */
 		N_("Tag _Implementation"),
 		"<control>d",
-		N_("Goto symbol definition"),
+		N_("Go to symbol definition"),
 		G_CALLBACK (on_goto_file_tag_impl_activate)
 	}	
 };
 
 static GtkActionEntry actions_search[] = {
   { 
-	"ActionEditSearchFindSymbol", GTK_STOCK_FIND, N_("_Find Symbol..."),
+	"ActionEditSearchFindSymbol", GTK_STOCK_FIND, N_("_Find Symbol…"),
 	"<control>l", N_("Find Symbol"),
     G_CALLBACK (on_find_symbol)
   }
@@ -545,7 +541,7 @@ on_editor_destroy (SymbolDBPlugin *sdb_plugin, IAnjutaEditor *editor)
 	DEBUG_PRINT ("%s", "on_editor_destroy ()");
 	if (!sdb_plugin->editor_connected || !sdb_plugin->dbv_view_tree)
 	{
-		DEBUG_PRINT ("%s", "on_editor_destroy (): returning....");
+		DEBUG_PRINT ("%s", "on_editor_destroy (): returning….");
 		return;
 	}
 	
@@ -555,7 +551,7 @@ on_editor_destroy (SymbolDBPlugin *sdb_plugin, IAnjutaEditor *editor)
 	/* was it the last file loaded? */
 	if (g_hash_table_size (sdb_plugin->editor_connected) <= 0)
 	{
-		DEBUG_PRINT ("%s", "displaying nothing...");
+		DEBUG_PRINT ("%s", "displaying nothing…");
 		symbol_db_view_locals_display_nothing (
 				SYMBOL_DB_VIEW_LOCALS (sdb_plugin->dbv_view_tree_locals), TRUE);
 	}
@@ -619,13 +615,8 @@ on_editor_saved (IAnjutaEditor *editor, GFile* file,
 		old_uri = NULL;
 
 	/* files_array will be freed once updating has taken place */
-	proc_id = 0;
-	if (symbol_db_engine_is_connected (sdb_plugin->sdbe_project))
-	{
-		proc_id = symbol_db_engine_update_files_symbols (sdb_plugin->sdbe_project, 
-							sdb_plugin->project_root_dir, files_array, TRUE);
-	}
-	
+	proc_id = symbol_db_engine_update_files_symbols (sdb_plugin->sdbe_project, 
+						sdb_plugin->project_root_dir, files_array, TRUE);
 	if (proc_id > 0)
 	{		
 		/* add a task so that scan_end_manager can manage this */
@@ -702,8 +693,8 @@ value_added_current_editor (AnjutaPlugin *plugin, const char *name,
 	{
 		sdb_plugin->buffer_update_semaphore = TRUE;
 	}
-	else if (symbol_db_engine_file_exists (sdb_plugin->sdbe_project, local_path) == TRUE)
-	{		
+	else
+	{
 		symbol_db_view_locals_update_list (
 					SYMBOL_DB_VIEW_LOCALS (sdb_plugin->dbv_view_tree_locals),
 					 sdb_plugin->sdbe_project, local_path, FALSE);
@@ -1176,7 +1167,7 @@ on_system_single_file_scan_end (SymbolDBEngine *dbe, gpointer data)
 	sdb_plugin->files_count_system_done++;	
 	if (sdb_plugin->files_count_system_done >= sdb_plugin->files_count_system)
 	{
-		message = g_strdup_printf (_("%s: Generating inheritances..."), 
+		message = g_strdup_printf (_("%s: Generating inheritances…"), 
 								   sdb_plugin->current_scanned_package);
 	}
 	else
@@ -1212,7 +1203,7 @@ on_project_single_file_scan_end (SymbolDBEngine *dbe, gpointer data)
 	
 	sdb_plugin->files_count_project_done++;	
 	if (sdb_plugin->files_count_project_done >= sdb_plugin->files_count_project)
-		message = g_strdup_printf (_("Generating inheritances..."));
+		message = g_strdup_printf (_("Generating inheritances…"));
 	else
 		message = g_strdup_printf (_("%d files scanned out of %d"), 
 							   sdb_plugin->files_count_project_done, sdb_plugin->files_count_project);
@@ -1250,8 +1241,7 @@ clear_project_progress_bar (SymbolDBEngine *dbe, gpointer data)
 						 sdb_plugin->sdbe_project);
 	
 	/* ok, enable local symbols view */
-	if (sdb_plugin->current_editor != NULL  &&
-	    IANJUTA_IS_EDITOR (sdb_plugin->current_editor) == FALSE)
+	if (!IANJUTA_IS_EDITOR (sdb_plugin->current_editor))
 	{
 		DEBUG_PRINT ("!IANJUTA_IS_EDITOR (sdb_plugin->current_editor))");
 		return;
@@ -1438,7 +1428,7 @@ do_import_project_sources (AnjutaPlugin *plugin, IAnjutaProjectManager *pm,
 	sdb_plugin->is_project_importing = TRUE;
 	enable_view_signals (sdb_plugin, FALSE, TRUE);
 	
-	DEBUG_PRINT ("Retrieving %d gbf sources of the project...",
+	DEBUG_PRINT ("Retrieving %d gbf sources of the project…",
 					 g_list_length (prj_elements_list));
 
 	/* create the storage array. The file names will be strdup'd and put here. 
@@ -1975,7 +1965,7 @@ on_project_root_added (AnjutaPlugin *plugin, const gchar *name,
 			}				
 		}
 		gtk_progress_bar_set_text (GTK_PROGRESS_BAR (sdb_plugin->progress_bar_project),
-								   _("Populating symbols' db..."));
+								   _("Populating symbol database…"));
 		id = g_idle_add ((GSourceFunc) gtk_progress_bar_pulse, 
 						 sdb_plugin->progress_bar_project);
 		gtk_widget_show (sdb_plugin->progress_bar_project);
@@ -2208,7 +2198,7 @@ symbol_db_activate (AnjutaPlugin *plugin)
 	gchar *ctags_path;
 	GtkWidget *label;
 	
-	DEBUG_PRINT ("SymbolDBPlugin: Activating SymbolDBPlugin plugin ...");
+	DEBUG_PRINT ("SymbolDBPlugin: Activating SymbolDBPlugin plugin …");
 	
 	/* Initialize gda library. */
 	gda_init ();
@@ -2377,15 +2367,15 @@ symbol_db_activate (AnjutaPlugin *plugin)
 
 	gtk_widget_show_all (sdb_plugin->dbv_hbox);
 	
-	sdb_plugin->progress_bar_project = gtk_progress_bar_new();	
+	sdb_plugin->progress_bar_project = gtk_progress_bar_new();
 	gtk_progress_bar_set_ellipsize (GTK_PROGRESS_BAR(sdb_plugin->progress_bar_project),
-									PANGO_ELLIPSIZE_MIDDLE);	
+									PANGO_ELLIPSIZE_MIDDLE);
 	g_object_ref (sdb_plugin->progress_bar_project);
 	
 	sdb_plugin->progress_bar_system = gtk_progress_bar_new();
 	gtk_progress_bar_set_ellipsize (GTK_PROGRESS_BAR(sdb_plugin->progress_bar_system),
 									PANGO_ELLIPSIZE_MIDDLE);
-	g_object_ref (sdb_plugin->progress_bar_system);	
+	g_object_ref (sdb_plugin->progress_bar_system);
 	
 	gtk_box_pack_start (GTK_BOX (sdb_plugin->dbv_main), sdb_plugin->dbv_notebook,
 						TRUE, TRUE, 0);
@@ -2394,6 +2384,7 @@ symbol_db_activate (AnjutaPlugin *plugin)
 	gtk_box_pack_start (GTK_BOX (sdb_plugin->dbv_main), sdb_plugin->progress_bar_system,
 						FALSE, FALSE, 0);	
 	gtk_widget_show_all (sdb_plugin->dbv_main);
+	
 
 	/* Local symbols */
 	sdb_plugin->scrolled_locals = gtk_scrolled_window_new (NULL, NULL);
@@ -2476,7 +2467,7 @@ symbol_db_activate (AnjutaPlugin *plugin)
 							  sdb_plugin->dbv_view_search_tab_label);
 
 	gtk_widget_show_all (sdb_plugin->dbv_notebook);
-
+	
 	/* setting focus to the tree_view*/
 	gtk_notebook_set_current_page (GTK_NOTEBOOK (sdb_plugin->dbv_notebook), 0);
 
@@ -2524,11 +2515,7 @@ symbol_db_activate (AnjutaPlugin *plugin)
 	
 	g_signal_connect (plugin->shell, "save-session", 
 					  G_CALLBACK (on_session_save), plugin);
-
-	/* be sure to hide the progress bars in case no project has been opened. */
-	gtk_widget_hide (sdb_plugin->progress_bar_project);
-	gtk_widget_hide (sdb_plugin->progress_bar_system);	
-	
+		
 	return TRUE;
 }
 
@@ -2539,7 +2526,7 @@ symbol_db_deactivate (AnjutaPlugin *plugin)
 	
 	sdb_plugin = ANJUTA_PLUGIN_SYMBOL_DB (plugin);
 
-	DEBUG_PRINT ("%s", "SymbolDBPlugin: Dectivating SymbolDBPlugin plugin ...");
+	DEBUG_PRINT ("%s", "SymbolDBPlugin: Dectivating SymbolDBPlugin plugin …");
 	
 	/* disconnect some signals */
 	g_signal_handlers_disconnect_by_func (G_OBJECT (sdb_plugin->dbv_view_tree_locals),
